Re: MinGW port usable
- From
Johannes Schindelin <johannes.schindelin@gmx.de>
- Date
- Jan 30, 2007, 16:49 UTC
- Message-ID
- <Pine.LNX.4.63.0701301746310.22628@wbgn013.biozentrum.uni-wuerzburg.de>
- In-Reply-To
- <20070130162835.GD25950@spearce.org>
Hi,
On Tue, 30 Jan 2007, Shawn O. Pearce wrote:
Show 11 quoted lines
> Johannes Schindelin <Johannes.Schindelin@gmx.de> wrote: > > > I wonder what the difference is between NO_MMAP=Yes and NO_MMAP= > > > on Windows. > > Cygwin: > > real 0m0.812s > > and > > real 0m2.094s > > > > IOW, the numbers are slightly worse (!) than with mmap(). > > Slightly? That's double the time!
Nope. What I meant is this: rev-list takes 0.8s without NO_MMAP, while it takes 0.75s with NO_MMAP, and similarly log takes 2.09s without NO_MMAP, while it takes 2.065 with NO_MMAP.
> > MinGW does not even have mmap(). > > But Windows has something almost there.
Yeah, CreateFile(). Very intuitive name.
> I just read a flame war thread about implementing mmap in libiberty for > MinGW by stealing source from Cygwin, and how the FSF might feel about > someone's dirty feet after playing rugby.
;-)
> Yea... Google is good. :)
Well, I had _horrible_ results in the last two weeks, slowly getting better.
Ciao, Dscho